( cd usr/bin ; rm -rf sc )
( cd usr/bin ; ln -sf /cdrom/usr/bin/sc sc )
( cd usr/bin ; rm -rf scqref )
( cd usr/bin ; ln -sf /cdrom/usr/bin/scqref scqref )
( cd usr/bin ; rm -rf psc )
( cd usr/bin ; ln -sf /cdrom/usr/bin/psc psc )
( cd usr/lib ; rm -rf sc )
( cd usr/lib ; ln -sf /cdrom/usr/lib/sc sc )
( cd usr ; rm -rf man )
( cd usr ; ln -sf /cdrom/usr/man man )
